@@ -49,8 +49,6 @@
 
 package com.openexchange.admin.reseller.rmi.impl;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import com.openexchange.admin.plugins.OXUserPluginInterface;
 import com.openexchange.admin.plugins.PluginException;
 import com.openexchange.admin.reseller.rmi.dataobjects.ResellerAdmin;
@@ -68,7 +66,7 @@ import com.openexchange.admin.rmi.exceptions.StorageException;
  */
 public class OXResellerUserImpl implements OXUserPluginInterface {
 
-    private final Log log = LogFactory.getLog(this.getClass());
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXResellerUserImpl.class);
 
     private OXResellerStorageInterface oxresell = null;
 
@@ -116,7 +114,7 @@ public class OXResellerUserImpl implements OXUserPluginInterface {
             //long tend = System.currentTimeMillis();
             //System.out.println("Time: " + (tend - tstart) + " ms");
         } catch (StorageException e) {
-            log.error(e.getMessage(),e);
+            log.error("",e);
             throw new PluginException(e);
         }
     }
