@@ -62,8 +62,6 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Map;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import com.openexchange.admin.exceptions.OXGenericException;
 import com.openexchange.admin.reseller.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.reseller.rmi.OXResellerTools;
@@ -101,7 +99,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
     private static AdminCache cache = null;
 
-    private static final Log log = LogFactory.getLog(OXResellerMySQLStorage.class);
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXResellerMySQLStorage.class);
 
     static {
         cache = ClientAdminThreadExtended.cache;
@@ -195,27 +193,27 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             doRollback(oxcon);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final NoSuchAlgorithmException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final UnsupportedEncodingException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } finally {
@@ -268,23 +266,23 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             doRollback(oxcon);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final NoSuchAlgorithmException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final UnsupportedEncodingException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } finally {
@@ -319,15 +317,15 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             doRollback(oxcon);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } finally {
@@ -369,10 +367,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             return ret.toArray(new ResellerAdmin[ret.size()]);
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -470,13 +468,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             return ret.toArray(new ResellerAdmin[ret.size()]);
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -544,13 +542,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             return true;
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -579,19 +577,19 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             doRollback(oxcon);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } finally {
@@ -605,7 +603,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             final ResellerAdmin adm = getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0];
             unownContextFromAdmin(ctx, adm);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -634,19 +632,19 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             doRollback(oxcon);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } finally {
@@ -675,16 +673,16 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             log.error(AdminCache.DATA_TRUNCATION_ERROR_MSG, dt);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final InvalidDataException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(oxcon, prep, rs);
@@ -722,13 +720,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             log.error(AdminCache.DATA_TRUNCATION_ERROR_MSG, dt);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(oxcon, prep, rs);
@@ -778,13 +776,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             log.error(AdminCache.DATA_TRUNCATION_ERROR_MSG, dt);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(oxcon, prep, rs);
@@ -811,10 +809,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             return ret;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -850,7 +848,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 throw new OXResellerException(Code.MAXIMUM_NUMBER_CONTEXT_REACHED, String.valueOf(maxvalue));
             }
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } finally {
             cache.closeConfigDBSqlStuff(null, prep, rs);
@@ -899,10 +897,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 throw new OXResellerException(Code.MAXIMUM_OVERALL_CONTEXT_QUOTA, String.valueOf(maxvalue));
             }
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } finally {
             cache.closeContextSqlStuff(oxcon, cid, true);
@@ -944,10 +942,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 throw new OXResellerException(Code.MAXIMUM_OVERALL_NUMBER_OF_CONTEXT_REACHED, String.valueOf(maxvalue));
             }
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } finally {
             cache.closeContextSqlStuff(oxcon, cid, true);
@@ -970,7 +968,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 }
             }
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } finally {
             cache.closeConfigDBSqlStuff(null, prep, rs);
@@ -1060,13 +1058,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 }
             }
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final ClassNotFoundException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final OXGenericException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } finally {
             cache.closeConfigDBSqlStuff(null, prep, rs);
@@ -1099,10 +1097,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 throw new OXResellerException(Code.MAXIMUM_NUMBER_OF_USERS_PER_CONTEXT_REACHED, String.valueOf(maxvalue));
             }
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } finally {
             cache.closeConfigDBSqlStuff(null, prep, rs);
@@ -1139,10 +1137,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
             }
         } catch (final ClassNotFoundException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final OXGenericException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         }
     }
@@ -1161,8 +1159,11 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         if( restrictions == null ) {
             restrictions = new HashSet<Restriction>();
         }
-        if( ! restrictions.contains(Restriction.SUBADMIN_CAN_CREATE_SUBADMINS) ) {
-            restrictions.add(new Restriction(Restriction.SUBADMIN_CAN_CREATE_SUBADMINS, "false"));
+        {
+            Restriction subadminCanCreateSubadminsRestriction = new Restriction(Restriction.SUBADMIN_CAN_CREATE_SUBADMINS, "false");
+            if( ! restrictions.contains(subadminCanCreateSubadminsRestriction) ) { // Contains is solely performed by name
+                restrictions.add(subadminCanCreateSubadminsRestriction);
+            }
         }
         if (restrictions != null && restrictions.size() > 0) {
             Connection con = null;
@@ -1206,22 +1207,22 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                     }
                 }
             } catch (final RuntimeException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw new StorageException(e.getMessage());
             } catch (final PoolException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw new StorageException(e.getMessage());
             } catch (final OXResellerException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw new StorageException(e.getMessage());
             } catch (final SQLException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw new StorageException(e.getMessage());
             } catch (final ClassNotFoundException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw new StorageException(e.getMessage());
             } catch (final OXGenericException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw new StorageException(e.getMessage());
             } finally {
                 cache.closeConfigDBSqlStuff(con, null);
@@ -1285,22 +1286,22 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 }
             }
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final NumberFormatException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final OXResellerException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final ClassNotFoundException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final OXGenericException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, null);
@@ -1328,10 +1329,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             return getData(new ResellerAdmin[] { new ResellerAdmin(rs.getInt(1)) })[0];
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } catch (final StorageException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw e;
         } finally {
             cache.closeConfigDBSqlStuff(null, prep, rs);
@@ -1374,15 +1375,15 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             doRollback(oxcon);
             throw AdminCache.parseDataTruncation(dt);
         } catch (final RuntimeException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw e;
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(oxcon);
             throw new StorageException(e.getMessage());
         } finally {
@@ -1403,7 +1404,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             con = cache.getConnectionForConfigDB();
             return getRestrictionsFromContext(ctx, con);
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, null, null);
@@ -1433,7 +1434,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             return res.size() > 0 ? res.toArray(new Restriction[res.size()]) : null;
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(null, prep, rs);
@@ -1474,19 +1475,19 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             con.commit();
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } catch (final ClassNotFoundException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } catch (final OXGenericException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } finally {
@@ -1509,11 +1510,11 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep.executeUpdate();
             con.commit();
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } finally {
@@ -1539,10 +1540,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             return rs.getString(1);
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -1582,10 +1583,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 prep.executeUpdate();
                 prep.close();
             } catch (final PoolException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw new StorageException(e.getMessage());
             } catch (final SQLException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 throw new StorageException(e.getMessage());
             } finally {
                 cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -1605,10 +1606,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep.executeUpdate();
             prep.close();
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -1630,10 +1631,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep.executeUpdate();
             prep.close();
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -1665,10 +1666,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 prep.close();
             }
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         } finally {
             cache.closeConfigDBSqlStuff(con, prep, rs);
@@ -1767,19 +1768,19 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
             con.commit();
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } catch (final SQLException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } catch (final ClassNotFoundException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } catch (final OXGenericException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             doRollback(con);
             throw new StorageException(e.getMessage());
         } finally {
@@ -1821,11 +1822,11 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 }
                 con.commit();
             } catch (final PoolException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 doRollback(con);
                 throw new StorageException(e.getMessage());
             } catch (final SQLException e) {
-                log.error(e.getMessage(), e);
+                log.error("", e);
                 doRollback(con);
                 throw new StorageException(e.getMessage());
             } finally {
